@@ -8,7 +8,7 @@ use File::Glob qw( bsd_glob );
 use File::Path qw( mkpath );
 
 # ABSTRACT: A framework for RESTful processing systems.
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 
 sub _testing
@@ -47,16 +47,14 @@ sub _slurp_pid ($)
 
 sub _dist_dir
 {
-  require Path::Class::File;
-  require Path::Class::Dir;
-  $_ = __FILE__; s{(Clustericious).pm}{.$1.devshare}; -e $_
-    ? Path::Class::File->new(__FILE__)->parent->parent->subdir('share')
-    : do {
-      require File::ShareDir;
-      Path::Class::Dir->new(
-        File::ShareDir::dist_dir('Clustericious'),
-      );
-    }
+  state $dir;
+  $dir //= do {
+    require Path::Class::Dir;
+    require File::ShareDir::Dist;
+    Path::Class::Dir->new(
+      File::ShareDir::Dist::dist_share('Clustericious') or die "unable to find share directory",
+    );
+  };
 }
 
 sub _generate_port
@@ -116,7 +114,7 @@ Clustericious - A framework for RESTful processing systems.
 
 =head1 VERSION
 
-version 1.25
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -238,6 +236,8 @@ Contributors:
 
 Curt Tilmes
 
+Yanick Champoux
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
