@@ -21,7 +21,7 @@ use Clustericious::Commands;
 use Path::Class::Dir;
 
 # ABSTRACT: Clustericious app base class
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 
 has commands => sub {
@@ -97,29 +97,6 @@ sub init_logging {
 }
 
 
-sub dump_api
-{
-  carp "Clustericious::App#dump_api is deprecated";
-  require Clustericious::Plugin::CommonRoutes;
-  Clustericious::Plugin::CommonRoutes->_dump_api(@_);
-}
-
-
-sub _dump_api_table_types
-{
-  carp "Clustericious::App#dump_api_table is deprecated";
-  require Clustericious::Plugin::CommonRoutes;
-  Clustericious::Plugin::CommonRoutes->_dump_api_table_types(@_);  
-}
-
-sub dump_api_table
-{
-  carp "Clustericious::App#dump_api_table is deprecated";
-  require Clustericious::Plugin::CommonRoutes;
-  Clustericious::Plugin::CommonRoutes->_dump_api_table($_[1]);
-}
-
-
 sub _my_dist_data
 {
   my $dir = bsd_glob '~/.local/share/Perl/dist/Clustericious';
@@ -192,7 +169,7 @@ Clustericious::App - Clustericious app base class
 
 =head1 VERSION
 
-version 1.25
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -229,22 +206,6 @@ and sets up logging for the client using log::log4perl.
 
 Initializing logging using ~/etc/log4perl.conf
 
-=head2 dump_api
-
- my @api = $app->dump_api;
-
-B<DEPRECATED>: will be removed on or after January 31, 2016.
-
-Dump out the API for this REST server.
-
-=head2 dump_api_table
-
- my $api = $app->dump_api_table( $table );
-
-B<DEPRECATED>: will be removed on or after January 31, 2016.
-
-Dump out the column information for the given table.
-
 =head2 config
 
  my $config = $app->config;
@@ -283,6 +244,8 @@ Contributors:
 
 Curt Tilmes
 
+Yanick Champoux
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
