@@ -4,11 +4,10 @@ use strict;
 use warnings;
 use Mojo::Base 'Clustericious::Command';
 use File::Find;
-use File::ShareDir 'dist_dir';
 use File::Basename qw( basename );
 
 # ABSTRACT: Clustericious command to generate a new Clustericious client
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 
 has description => <<'EOF';
@@ -73,7 +72,7 @@ Clustericious::Command::generate::client - Clustericious command to generate a n
 
 =head1 VERSION
 
-version 1.25
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -97,6 +96,8 @@ Contributors:
 
 Curt Tilmes
 
+Yanick Champoux
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
